import { PrismaClient } from '@prisma/client'
import Invoice from '../classes/Invoice'
import InvoiceItem from '../classes/InvoiceItem'

export default async function getInvoices(prisma: PrismaClient, page: number, limit: number) {
	const invoices = await prisma.invoice.findMany({
		skip: (page - 1) * limit,
		take: limit,
		orderBy: [{
			invoice_date: 'desc'
		}, {
			invoice_suffix_code: 'desc'
		}]
	})

	const result = invoices.map(async invoice => {
		const invoiceItemsRaw = await prisma.invoiceItem.findMany({
			where: {
				invoice_suffix_code: invoice.invoice_suffix_code,
				invoice_date: invoice.invoice_date
			}
		})

		const invoiceItems = invoiceItemsRaw.map(item => {
			return new InvoiceItem(item.item_id, item.item_description, item.item_quantity, item.item_unit, item.item_unit_price)
		})

		const payer = {
			id: invoice.payer_id,
			name: invoice.invoice_payer_name,
			address: invoice.invoice_payer_address,
			abn: invoice.invoice_payer_abn ?? undefined
		}
		return new Invoice(invoice.invoice_suffix_code, invoice.invoice_date, [invoice.invoice_billing_period_start, invoice.invoice_billing_period_end], invoiceItems, invoice.invoice_due_date, payer)
	})

	return result
}