import { PrismaClient } from '@prisma/client'
import dayjs from 'dayjs'
import { ErrorDescEnum, HttpError } from '../classes/HttpError'
import Invoice from '../classes/Invoice'
import InvoiceItem from '../classes/InvoiceItem'

export default async (prisma: PrismaClient, invoiceIssueDateString: string, invoiceSuffix: number) => {
	const invoiceIssueDate = dayjs(invoiceIssueDateString, 'YYYYMMDD').toDate()

	const invoice = await prisma.invoice.findUnique({
		where: {
			invoice_date_invoice_suffix_code: {
				invoice_date: invoiceIssueDate,
				invoice_suffix_code: invoiceSuffix
			}
		}
	})
	console.log(invoiceIssueDate, invoiceSuffix)
	console.log(invoice)
	if (!invoice) throw new HttpError(ErrorDescEnum.related_item_not_found, 404)
	
	const items = await prisma.invoiceItem.findMany({
		where: {
			invoice_suffix_code: invoiceSuffix,
			invoice_date: invoiceIssueDate
		}
	})

	const payer = {
		id: invoice.payer_id,
		name: invoice.invoice_payer_name,
		address: invoice.invoice_payer_address,
		abn: invoice.invoice_payer_abn ?? undefined
	}

	const invoiceItems = items.map(item => {
		return new InvoiceItem(item.item_id, item.item_description, item.item_quantity, item.item_unit, item.item_unit_price)
	})

	const invoiceInstance = new Invoice(invoice.invoice_suffix_code, invoice.invoice_date, [invoice.invoice_billing_period_start, invoice.invoice_billing_period_end], invoiceItems, invoice.invoice_due_date, payer)
	if (invoice.invoice_note) await invoiceInstance.setNote(invoice.invoice_note)

	return invoiceInstance
}